==> ioc-liturgical-react-1.0.3.tgz: package/es/modules/SchemaBasedAddButton.js <==
var _class, _temp, _initialiseProps, _SchemaBasedAddButton;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { Button } from 'react-bootstrap';
import MessageIcons from '../helpers/MessageIcons';
import ModalSearchOntologyWithCallback from './ModalSearchOntologyWithCallback';
import ModalSearchTextWithCallback from './ModalSearchTextWithCallback';
import ModalNewEntryForm from './ModalNewEntryForm';
import FontAwesome from 'react-fontawesome';
import UiSchemas from "../classes/UiSchemas";

/**
 * Provides an Add button for adding an entry that is based on a json schema
 */
var SchemaBasedAddButton = (_temp = _class = function (_React$Component) {
  _inherits(SchemaBasedAddButton, _React$Component);

  function SchemaBasedAddButton(props) {
    _classCallCheck(this, SchemaBasedAddButton);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    var uiSchemas = {};
    if (props.session && props.session.uiSchemas) {
      uiSchemas = new UiSchemas(props.session.uiSchemas.formsDropdown, props.session.uiSchemas.formsSchemas, props.session.uiSchemas.forms);
    }

    var labels = props.session.labels;
    var labelTopics = props.session.labelTopics;

    _this.state = {
      labels: {
        thisClass: labels[labelTopics.schemaBasedAddButton],
        messages: labels[labelTopics.messages],
        resultsTableLabels: labels[labelTopics.resultsTable],
        references: labels[labelTopics.ViewReferences]
      },
      session: {
        uiSchemas: uiSchemas
      },
      messageIcons: MessageIcons.getMessageIcons(),
      messageIcon: MessageIcons.getMessageIcons().info,
      message: labels[labelTopics.messages].initial,
      idTopicType: _this.props.formData["partTypeOfTopic"],
      idKeyType: _this.props.formData["partTypeOfKey"],
      showModal: false,
      idSelected: false,
      idLibrary: _this.props.idLibrary,
      idTopic: _this.props.idTopic,
      idTopicValue: "",
      idKey: _this.props.idKey,
      idKeyValue: "",
      initialOntologyType: "Animal",
      restPath: _this.props.restPath,
      uiSchema: _this.props.uiSchema,
      schema: _this.props.schema,
      formData: _this.props.formData
    };

    _this.handleStateChange = _this.handleStateChange.bind(_this);
    _this.handleAddButtonClick = _this.handleAddButtonClick.bind(_this);
    _this.handleIdBuilderClose = _this.handleIdBuilderClose.bind(_this);
    _this.handleModalClose = _this.handleModalClose.bind(_this);
    _this.handleModalSubmit = _this.handleModalSubmit.bind(_this);
    _this.getContent = _this.getContent.bind(_this);
    _this.setFormData = _this.setFormData.bind(_this);

    _this.handleIdLibrarySelection = _this.handleIdLibrarySelection.bind(_this);
    _this.handleIdTopicSelection = _this.handleIdTopicSelection.bind(_this);
    _this.handleIdKeySelection = _this.handleIdKeySelection.bind(_this);
    return _this;
  }

  // if we need to do something after setState, do it here...


  SchemaBasedAddButton.prototype.render = function render() {
    return React.createElement(
      'span',
      null,
      this.getContent()
    );
  };

  return SchemaBasedAddButton;
}(React.Component), _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.componentWillMount = function () {};

  this.componentDidMount = function () {
    // make any initial function calls here...
  };

  this.componentWillReceiveProps = function (nextProps) {
    var labels = nextProps.session.labels;
    var labelTopics = nextProps.session.labelTopics;

    _this2.setState(function (prevState, props) {
      return {
        labels: {
          thisClass: labels[labelTopics.schemaBasedAddButton],
          messages: labels[labelTopics.messages],
          resultsTableLabels: labels[labelTopics.resultsTable],
          references: labels[labelTopics.ViewReferences]
        },
        message: labels[labelTopics.messages].initial
      };
    }, function () {
      return this.handleStateChange("place holder");
    });
  };

  this.handleStateChange = function (parm) {
    // call a function if needed
  };

  this.handleIdLibrarySelection = function (library) {
    if (library) {
      _this2.setState({
        idLibrary: library
      });
    }
  };

  this.handleIdTopicSelection = function (topic, value) {
    _this2.setState({
      idTopic: topic,
      idTopicValue: value
    });
  };

  this.handleIdKeySelection = function (id, value, seq, schema) {
    var schemaId = _this2.state.session.uiSchemas.getLinkCreateSchemaIdForSchemaId(schema);
    var formData = _this2.state.session.uiSchemas.getForm(schemaId);

    _this2.setState({
      idKey: id,
      idKeyValue: value,
      idKeySeq: seq,
      idSelected: true,
      idSchema: schemaId,
      idTopicType: formData["partTypeOfTopic"],
      idKeyType: formData["partTypeOfKey"],
      restPath: _this2.state.session.uiSchemas.getHttpPostPathForSchema(schemaId),
      uiSchema: _this2.state.session.uiSchemas.getUiSchema(schemaId),
      schema: _this2.state.session.uiSchemas.getSchema(schemaId),
      formData: formData
    });
  };

  this.handleAddButtonClick = function () {
    var idSelected = false;
    if (_this2.state.idKeyType === "TIMESTAMP") {
      idSelected = true;
    }
    _this2.setState({
      idSelected: idSelected,
      showModal: true
    });
  };

  this.handleIdBuilderClose = function () {
    var idSelected = _this2.state.idKey && _this2.state.idKey.length > 0;
    _this2.setState({
      idSelected: idSelected,
      showModal: idSelected
    });
  };

  this.handleModalClose = function () {
    _this2.setState({
      showModal: false
    });
    _this2.props.onClose();
  };

  this.handleModalSubmit = function (_ref) {
    var formData = _ref.formData;

    if (_this2.props.onSubmit) {
      console.log("SchemaBasedAddButton.handleModalSubmit");
      console.log(formData);
      _this2.props.onSubmit(formData);
    }
  };

  this.setFormData = function () {
    var formData = _this2.state.formData;
    formData.library = _this2.props.idLibrary;
    formData.topic = _this2.props.idTopic;
    formData.key = _this2.state.idKey;
    formData.id = _this2.props.idLibrary + "~" + _this2.props.idTopic + "~" + _this2.state.idKey;
    formData.seq = _this2.props.seq;
    formData.status = "FINALIZED";
    return formData;
  };

  this.getContent = function () {
    if (_this2.state.showModal) {
      if (_this2.state.idSelected) {
        return React.createElement(ModalNewEntryForm, {
          session: _this2.props.session,
          restPath: _this2.state.restPath,
          uiSchema: _this2.state.uiSchema,
          schema: _this2.state.schema,
          formData: _this2.setFormData(),
          title: _this2.props.title,
          fromId: _this2.props.fromId,
          fromText: _this2.props.fromText,
          toId: _this2.state.idKey,
          toText: _this2.state.idKeyValue,
          fromTitle: _this2.state.labels.references.theText,
          toTitle: _this2.state.labels.references.refersTo,
          onSubmit: _this2.handleModalSubmit,
          onClose: _this2.handleModalClose
        });
      } else {
        switch (_this2.state.idKeyType) {
          case "ID_OF_SELECTED_BIBLICAL_VERSE":
            return React.createElement(ModalSearchTextWithCallback, {
              session: _this2.props.session,
              initialDocType: "Biblical",
              onCallback: _this2.handleIdKeySelection,
              onClose: _this2.handleIdBuilderClose
            });
          case "ID_OF_SELECTED_ONTOLOGY_INSTANCE":
            return React.createElement(ModalSearchOntologyWithCallback, {
              session: _this2.props.session,
              initialDocType: "Animal",
              onCallback: _this2.handleIdKeySelection,
              onClose: _this2.handleIdBuilderClose
            });
        }
      }
    } else {
      return React.createElement(
        Button,
        {
          className: 'Schema-Based-Add-Button',
          bsStyle: 'primary',
          bsSize: "xsmall",
          onClick: _this2.handleAddButtonClick },
        React.createElement(FontAwesome, {
          className: 'App-Add-ico',
          name: 'plus' })
      );
    }
  };
}, _temp);


process.env.NODE_ENV !== "production" ? SchemaBasedAddButton.propTypes = (_SchemaBasedAddButton = {
  session: PropTypes.object.isRequired,
  restPath: PropTypes.string.isRequired,
  uiSchema: PropTypes.object.isRequired,
  schema: PropTypes.object.isRequired,
  formData: PropTypes.object.isRequired,
  title: PropTypes.string,
  idLibrary: PropTypes.string.isRequired,
  idTopic: PropTypes.string.isRequired,
  idKey: PropTypes.string.isRequired,
  seq: PropTypes.string.isRequired
}, _SchemaBasedAddButton['title'] = PropTypes.string.isRequired, _SchemaBasedAddButton.fromTitle = PropTypes.string, _SchemaBasedAddButton.fromId = PropTypes.string, _SchemaBasedAddButton.fromText = PropTypes.string, _SchemaBasedAddButton.toTitle = PropTypes.string, _SchemaBasedAddButton.onClose = PropTypes.func.isRequired, _SchemaBasedAddButton.onSubmit = PropTypes.func, _SchemaBasedAddButton) : void 0;

// set default values for props here
SchemaBasedAddButton.defaultProps = {
  languageCode: "en",
  title: "",
  fromTitle: "",
  fromId: "",
  fromText: "",
  toTitle: ""
};

export default SchemaBasedAddButton;

==> ioc-liturgical-react-1.0.6.tgz: package/es/modules/SchemaBasedAddButton.js <==
var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { Button } from 'react-bootstrap';
import MessageIcons from '../helpers/MessageIcons';
import ModalSearchOntologyWithCallback from './ModalSearchOntologyWithCallback';
import ModalSearchTextWithCallback from './ModalSearchTextWithCallback';
import ModalNewEntryForm from './ModalNewEntryForm';
import FontAwesome from 'react-fontawesome';
import UiSchemas from "../classes/UiSchemas";

/**
 * Provides an Add button for adding an entry that is based on a json schema
 */
var SchemaBasedAddButton = (_temp = _class = function (_React$Component) {
  _inherits(SchemaBasedAddButton, _React$Component);

  function SchemaBasedAddButton(props) {
    _classCallCheck(this, SchemaBasedAddButton);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    var uiSchemas = {};
    if (props.session && props.session.uiSchemas) {
      uiSchemas = new UiSchemas(props.session.uiSchemas.formsDropdown, props.session.uiSchemas.formsSchemas, props.session.uiSchemas.forms);
    }

    var labels = props.session.labels;
    var labelTopics = props.session.labelTopics;

    _this.state = {
      labels: {
        thisClass: labels[labelTopics.schemaBasedAddButton],
        messages: labels[labelTopics.messages],
        resultsTableLabels: labels[labelTopics.resultsTable],
        references: labels[labelTopics.ViewReferences]
      },
      session: {
        uiSchemas: uiSchemas
      },
      messageIcons: MessageIcons.getMessageIcons(),
      messageIcon: MessageIcons.getMessageIcons().info,
      message: labels[labelTopics.messages].initial,
      idTopicType: _this.props.formData["partTypeOfTopic"],
      idKeyType: _this.props.formData["partTypeOfKey"],
      showModal: false,
      idSelected: false,
      idLibrary: _this.props.idLibrary,
      idTopic: _this.props.idTopic,
      idTopicValue: "",
      idKey: _this.props.idKey,
      idKeyValue: "",
      initialOntologyType: "Animal",
      restPath: _this.props.restPath,
      uiSchema: _this.props.uiSchema,
      schema: _this.props.schema,
      formData: _this.props.formData
    };

    _this.handleStateChange = _this.handleStateChange.bind(_this);
    _this.handleAddButtonClick = _this.handleAddButtonClick.bind(_this);
    _this.handleIdBuilderClose = _this.handleIdBuilderClose.bind(_this);
    _this.handleModalClose = _this.handleModalClose.bind(_this);
    _this.handleModalSubmit = _this.handleModalSubmit.bind(_this);
    _this.getContent = _this.getContent.bind(_this);
    _this.setFormData = _this.setFormData.bind(_this);

    _this.handleIdLibrarySelection = _this.handleIdLibrarySelection.bind(_this);
    _this.handleIdTopicSelection = _this.handleIdTopicSelection.bind(_this);
    _this.handleIdKeySelection = _this.handleIdKeySelection.bind(_this);
    return _this;
  }

  // if we need to do something after setState, do it here...


  SchemaBasedAddButton.prototype.render = function render() {
    return React.createElement(
      'span',
      null,
      this.getContent()
    );
  };

  return SchemaBasedAddButton;
}(React.Component), _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.componentWillMount = function () {};

  this.componentDidMount = function () {
    // make any initial function calls here...
  };

  this.componentWillReceiveProps = function (nextProps) {
    var labels = nextProps.session.labels;
    var labelTopics = nextProps.session.labelTopics;

    _this2.setState(function (prevState, props) {
      return {
        labels: {
          thisClass: labels[labelTopics.schemaBasedAddButton],
          messages: labels[labelTopics.messages],
          resultsTableLabels: labels[labelTopics.resultsTable],
          references: labels[labelTopics.ViewReferences]
        },
        message: labels[labelTopics.messages].initial
      };
    }, function () {
      return this.handleStateChange("place holder");
    });
  };

  this.handleStateChange = function (parm) {
    // call a function if needed
  };

  this.handleIdLibrarySelection = function (library) {
    if (library) {
      _this2.setState({
        idLibrary: library
      });
    }
  };

  this.handleIdTopicSelection = function (topic, value) {
    _this2.setState({
      idTopic: topic,
      idTopicValue: value
    });
  };

  this.handleIdKeySelection = function (id, value, seq, schema) {
    var schemaId = _this2.state.session.uiSchemas.getLinkCreateSchemaIdForSchemaId(schema);
    var formData = _this2.state.session.uiSchemas.getForm(schemaId);

    _this2.setState({
      idKey: id,
      idKeyValue: value,
      idKeySeq: seq,
      idSelected: true,
      idSchema: schemaId,
      idTopicType: formData["partTypeOfTopic"],
      idKeyType: formData["partTypeOfKey"],
      restPath: _this2.state.session.uiSchemas.getHttpPostPathForSchema(schemaId),
      uiSchema: _this2.state.session.uiSchemas.getUiSchema(schemaId),
      schema: _this2.state.session.uiSchemas.getSchema(schemaId),
      formData: formData
    });
  };

  this.handleAddButtonClick = function () {
    var idSelected = false;
    if (_this2.state.idKeyType === "TIMESTAMP") {
      idSelected = true;
    }
    _this2.setState({
      idSelected: idSelected,
      showModal: true
    });
  };

  this.handleIdBuilderClose = function () {
    var idSelected = _this2.state.idKey && _this2.state.idKey.length > 0;
    _this2.setState({
      idSelected: idSelected,
      showModal: idSelected
    });
  };

  this.handleModalClose = function () {
    _this2.setState({
      showModal: false
    });
    _this2.props.onClose();
  };

  this.handleModalSubmit = function (_ref) {
    var formData = _ref.formData;

    if (_this2.props.onSubmit) {
      _this2.props.onSubmit(formData);
    }
  };

  this.setFormData = function () {
    var date = new Date();
    var month = (date.getMonth() + 1).toString().padStart(2, "0");
    var day = date.getDate().toString().padStart(2, "0");
    var hour = date.getHours().toString().padStart(2, "0");
    var minute = date.getMinutes().toString().padStart(2, "0");
    var second = date.getSeconds().toString().padStart(2, "0");
    var key = date.getFullYear() + "." + month + "." + day + ".T" + hour + "." + minute + "." + second;
    var formData = _this2.state.formData;
    formData.library = _this2.props.idLibrary;
    formData.topic = _this2.props.idTopic;
    formData.key = key; //this.state.idKey;
    formData.id = _this2.props.idLibrary + "~" + _this2.props.idTopic + "~" + key;
    formData.seq = formData.id;
    formData.status = "FINALIZED";
    return formData;
  };

  this.getContent = function () {
    if (_this2.state.showModal) {
      if (_this2.state.idSelected) {
        return React.createElement(ModalNewEntryForm, {
          session: _this2.props.session,
          restPath: _this2.state.restPath,
          uiSchema: _this2.state.uiSchema,
          schema: _this2.state.schema,
          formData: _this2.setFormData(),
          title: _this2.props.title,
          fromId: _this2.props.fromId,
          fromText: _this2.props.fromText,
          toId: _this2.state.idKey,
          toText: _this2.state.idKeyValue,
          fromTitle: _this2.state.labels.references.theText,
          toTitle: _this2.state.labels.references.refersTo,
          onSubmit: _this2.handleModalSubmit,
          onClose: _this2.handleModalClose
        });
      } else {
        switch (_this2.state.idKeyType) {
          case "ID_OF_SELECTED_BIBLICAL_VERSE":
            return React.createElement(ModalSearchTextWithCallback, {
              session: _this2.props.session,
              initialDocType: "Biblical",
              onCallback: _this2.handleIdKeySelection,
              onClose: _this2.handleIdBuilderClose
            });
          case "ID_OF_SELECTED_ONTOLOGY_INSTANCE":
            return React.createElement(ModalSearchOntologyWithCallback, {
              session: _this2.props.session,
              initialDocType: "Animal",
              onCallback: _this2.handleIdKeySelection,
              onClose: _this2.handleIdBuilderClose
            });
        }
      }
    } else {
      return React.createElement(
        Button,
        {
          className: 'Schema-Based-Add-Button',
          bsStyle: 'primary',
          bsSize: "xsmall",
          onClick: _this2.handleAddButtonClick },
        React.createElement(FontAwesome, {
          className: 'App-Add-ico',
          name: 'plus' })
      );
    }
  };
}, _temp);


process.env.NODE_ENV !== "production" ? SchemaBasedAddButton.propTypes = {
  session: PropTypes.object.isRequired,
  restPath: PropTypes.string.isRequired,
  uiSchema: PropTypes.object.isRequired,
  schema: PropTypes.object.isRequired,
  formData: PropTypes.object.isRequired,
  idLibrary: PropTypes.string.isRequired,
  idTopic: PropTypes.string.isRequired,
  idKey: PropTypes.string.isRequired,
  seq: PropTypes.string.isRequired,
  title: PropTypes.string.isRequired,
  fromTitle: PropTypes.string,
  fromId: PropTypes.string,
  fromText: PropTypes.string,
  toTitle: PropTypes.string,
  onClose: PropTypes.func.isRequired,
  onSubmit: PropTypes.func
} : void 0;

// set default values for props here
SchemaBasedAddButton.defaultProps = {
  languageCode: "en",
  title: "",
  fromTitle: "",
  fromId: "",
  fromText: "",
  toTitle: ""
};

export default SchemaBasedAddButton;
